@@ -13,7 +13,7 @@ class EventCounter(TriggerMixin, BaseCounter):
 
     def __init__(self, name, events=None):
         self.value = None
-        super(EventCounter, self).__init__(name)
+        super(EventCounter, self).__init__(name, events=events)
 
     def _get_value(self):
         return AccumulativeCounterValue(self.value)
@@ -71,7 +71,7 @@ class AverageWindowCounter(AutoDispatch, BaseCounter):
         else:
             v = sum(self.values, 0.0) / len(self.values)
 
-        return AverageCounterValue(v,len(self.values))
+        return AverageCounterValue(v, len(self.values))
 
     def _trim_window(self):
         window_limit = self._get_current_time() - self.window_size
@@ -158,6 +158,12 @@ class ThreadTimeCategorizer(BaseListener):
         for cat in categories:
             self.category_timers[cat] = timer_class()
 
+    def get_times(self):
+        ret = []
+        for k, v in self.category_timers.iteritems():
+            ret.append((self.name + "." + k, v.get_accumulated_time()))
+        return ret
+
     def report_event(self, name, property, param):
         if property == "start":
             cat_timer = self.category_timers.get(name)
@@ -181,8 +187,8 @@ class ThreadTimeCategorizer(BaseListener):
 
     def raise_value_events(self, clear=False):
         """ raises category total time as value events. """
-        for k, v in self.category_timers.iteritems():
-            THREAD_DISPATCHER.dispatch_event(self.name + "." + k, "value", v.get_accumulated_time())
+        for k, v in self.get_times():
+            THREAD_DISPATCHER.dispatch_event(k, "value", v)
 
         if clear:
             self.category_timers.clear()
